@@ -15,10 +15,6 @@
 
 using namespace GraphTheory;
 
-TestRocs1FileFormat::TestRocs1FileFormat()
-{
-}
-
 void TestRocs1FileFormat::serializeUnserializeTest()
 {
     GraphDocumentPtr document = GraphDocument::create();
@@ -43,7 +39,7 @@ void TestRocs1FileFormat::serializeUnserializeTest()
     Edge::create(nodes["e"], nodes["a"]);
 
     // serialize to file
-    Rocs1FileFormat format(this, KPluginMetaData(), QVariantList());
+    Rocs1FileFormat format;
     format.setFile(QUrl::fromLocalFile("test.graph"));
     format.writeFile(document);
     QVERIFY(format.hasError() == false);
@@ -87,7 +83,7 @@ void TestRocs1FileFormat::serializeUnserializeTypesTest()
     Edge::create(nodes["a"], nodes["b"]);
 
     // serialize to file
-    Rocs1FileFormat format(this, KPluginMetaData(), QVariantList());
+    Rocs1FileFormat format;
     format.setFile(QUrl::fromLocalFile("testtypes.graph"));
     format.writeFile(document);
     QVERIFY(format.hasError() == false);
